<?php

namespace App\Http\Controllers;

use App\Models\Leaderboard1;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Validator;

class AdminController extends Controller
{
    public function index() {
        $users = Leaderboard1::get()->all();
        return view('admin.dashboard', [
            'users' => $users
        ]);
    }

    public function store(Request $request) {
        $validator = Validator::make($request->all(), [
            'name' => 'required',
            'score' => 'required|numeric|digits_between:1,2',
            'minutes' => 'required|numeric|digits_between:1,2|between:0,59',
            'seconds' => 'required|numeric|digits_between:1,2|between:0,59',
            'milli' => 'required|numeric|digits_between:1,3|between:0,999'
        ],
        [
            'digits_between' => 'The :attribute field must not have more than :max digits'
        ]);

        if($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput()->with('mode', 'add');
        }

        $user = Leaderboard1::create([
            'name' => $request->name,
            'score' => $request->score,
            'minutes' => $request->minutes,
            'seconds' => $request->seconds,
            'milli' => $request->milli
        ]);

        return redirect(route('admin.dashboard'));
    }

    public function editModal($id) {
        $user = Leaderboard1::findOrFail($id);
        
        $modal = '<div class="form-group">';
        $modal .= '<div class="col-md-12">';
        $modal .= '<label for="name" class="col-md-6">Name</label>';
        $modal .= '<input type="text" name="name" class="form-control col-md-12 @error("name") is-invalid @enderror" value="'.$user->name.'" required>';
        $modal .= '</div>';
        $modal .= '</div>';
        $modal .= '<div class="form-group">';
        $modal .= '<div class="col-md-12">';
        $modal .= '<label for="name" class="col-md-6">Hours</label>';
        $modal .= '<input type="text" name="score" class="form-control col-md-12 @error("score") is-invalid @enderror"" value="'.$user->score.'" required>';
        $modal .= '</div>';
        $modal .= '</div>';
        $modal .= '<div class="form-group">';
        $modal .= '<div class="col-md-12">';
        $modal .= '<label for="name" class="col-md-6">Minutes</label>';
        $modal .= '<input type="text" name="minutes" class="form-control col-md-12 @error("minutes") is-invalid @enderror"" value="'.$user->minutes.'" required>';
        $modal .= '</div>';
        $modal .= '</div>';
        $modal .= '<div class="form-group">';
        $modal .= '<div class="col-md-12">';
        $modal .= '<label for="name" class="col-md-6">Seconds</label>';
        $modal .= '<input type="text" name="seconds" class="form-control col-md-12 @error("seconds") is-invalid @enderror"" value="'.$user->seconds.'" required>';
        $modal .= '</div>';
        $modal .= '</div>';
        $modal .= '<div class="form-group">';
        $modal .= '<div class="col-md-12">';
        $modal .= '<label for="name" class="col-md-6">Milliseconds</label>';
        $modal .= '<input type="text" name="milli" class="form-control col-md-12 @error("milli") is-invalid @enderror"" value="'.$user->milli.'" required>';
        $modal .= '</div>';
        $modal .= '</div>';

        echo $modal;
    }

    public function update(Request $request, $id) {
        // dd($request);
        $user = Leaderboard1::findOrFail($id);

        $validator = Validator::make($request->all(), [
            'name' => 'required',
            'score' => 'required|numeric|digits_between:1,2',
            'minutes' => 'required|numeric|digits_between:1,2|between:0,59',
            'seconds' => 'required|numeric|digits_between:1,2|between:0,59',
            'milli' => 'required|numeric|digits_between:1,3|between:0,999'
        ],
        [
            'digits_between' => 'The :attribute field must not have more than :max digits'
        ]);

        if($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput()->with('error', 'Check your input.');
        }

        $user->name = $request->name;
        $user->score = $request->score;
        $user->minutes = $request->minutes;
        $user->seconds = $request->seconds;
        $user->milli = $request->milli;
        $user->save();

        return redirect(route('admin.dashboard'));
    }
}
