<?php

namespace App\Http\Controllers\Api;

use App\Models\Item;
use App\Models\AutoDraw;
use App\Models\Participant;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Http\Resources\ItemResource;
use App\Http\Resources\SeedResource;
use App\Http\Requests\StoreItemRequest;
use Illuminate\Support\Facades\Storage;
use App\Http\Requests\UpdateItemRequest;
use App\Http\Resources\ParticipantResource;
use App\Http\Requests\StoreParticipantRequest;
use App\Http\Requests\UpdateParticipantRequest;
use Maatwebsite\Excel\Facades\Excel;
use App\Imports\ParticipantsImport;

class ItemController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response\Json\AnonymousResourceCollection
     */
    public function index()
    {
        return ItemResource::collection(Item::query()->orderBy('id', 'asc')->get());
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \App\Http\Requests\StoreParticipantRequest  $request
     * @return \Illuminate\Http\Response
     */
    public function store(StoreParticipantRequest $request)
    {
        $data = $request->validated();
        $item = Participant::create($data);
        return response(new ParticipantResource($item), 201);
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Participant  $item
     * @return \Illuminate\Http\Response
     */
    public function show(Participant $item)
    {
        return new ParticipantResource($item);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \App\Http\Requests\UpdateParticipantRequest  $request
     * @param  \App\Models\Participant  $item
     * @return \Illuminate\Http\Response
     */
    public function update(UpdateParticipantRequest $request, Participant $item)
    {
        $data = $request->validated();
        $item->update($data);
    }

    public function seed(Request $request, $id) {
        $data = AutoDraw::findOrFail($id);
        $data->check = $request->check;
        $data->save();
        return response('', 201);
    }

    public function checkSeed() {
        $data = AutoDraw::get()->first();
        return $data;
        // return json()->response([$data]);
    }

    // public function checkSeedDelete(Request $request, $id) {
    //     $data = AutoDraw::findOrFail($id);
    //     $data->check = $request->check;
    //     // return json()->response([$data]);
    // }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Participant  $item
     * @return \Illuminate\Http\Response
     */
    public function destroy(Participant $item)
    {
        $item->delete();
        return response("", 204);
    }

    public function import(Request $request)
    {
        $request->validate([
            'file' => 'required|mimes:xlsx', // Ensure only XLSX files are allowed
        ]);
    
        $file = $request->file('file');
    
        // Import participants from the Excel file
        Excel::import(new ParticipantsImport, $file);
    
        return redirect()->back()->with('success', 'Participants imported successfully');
    }
}
