@extends('layouts.administrator')
@section('title', 'Asphalt')
@section('content')
    <div class="container mt-10">
        @if(Session::get('error'))
        <div class="row">
            <div class="col-md-12">
                <div class="alert alert-danger">
                <h5>{{ Session::get('error') }}</h5>
                @foreach($errors->all() as $error)
                    <li>{{ $error }}</li>
                @endforeach
                </div>
            </div>
        </div>
        @endif
        <div class="row justify-content-center">
            <div class="col-md-12">
                <div class="card">
                    <div class="card-header">Asphalt 9:Legends</div>
                    <div class="card-body">
                        <div class="action-buttons my-2">
                            <div class="text-right">
                                <button data-toggle="modal" data-target="#userModal" class="btn btn-secondary"><i class="fa fa-user mr-1 pr-1" aria-hidden="true"></i>Add Participant</button>
                            </div>
                        </div>
                        <div class="datatable">
                            <table id="aTable" class="table table-bordered table-hover" cellspacing="0" width="100%">
                                <thead>
                                    <tr>
                                        <th>ID</th>
                                        <th>Name</th>
                                        <th>Score</th>
                                        <th>Actions</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    @foreach($users as $user)
                                        <tr>
                                            <td>{{ $user->id }}</td>
                                            <td>{{ $user->name }}</td>
                                            <td>{{ str_pad($user->score, 2, 0, STR_PAD_LEFT).':'.str_pad($user->minutes, 2, 0, STR_PAD_LEFT).':'.str_pad($user->seconds, 2, 0, STR_PAD_LEFT).'.'.str_pad($user->milli, 3, 0, STR_PAD_RIGHT) }}</td>
                                            <td>
                                                <a name="view" href="#"  class="btn btn-success edit__participant" id="{{$user->id}}">Edit</a>
                                                <div class="modal fade edit-modal" tabindex="-1" role="dialog" id="edit-{{$user->id}}" aria-labelledby="detailsModalCenterTitle" aria-hidden="true">
                                                    <div class="modal-dialog modal-dialog-centered" role="document">
                                                        <div class="modal-content">
                                                            <div class="modal-header">
                                                                <h5 class="modal-title">Edit Score</h5>
                                                                <button type="button" class="btn-close" data-dismiss="modal" aria-label="Close">
                                                                <span aria-hidden="true">&times;</span>
                                                                </button>
                                                            </div>
                                                            <form action="{{ route('user.update', $user->id) }}" method="POST">
                                                            @csrf
                                                            @method('PUT')
                                                            <div class="modal-body" id="edit-details-{{$user->id}}">
                                                            </div>
                                                            <div class="modal-footer">
                                                                <input type="submit" class="btn btn-primary" value="Update">
                                                                <button type="button" class="btn btn-secondary" data-dismiss="modal">Close</button>
                                                            </div>
                                                            </form>
                                                        </div>
                                                    </div>
                                                </div>
                                            </td>
                                        </tr>
                                    @endforeach
                                </tbody>
                            </table>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <div class="modal fade" id="userModal" tabindex="-1" role="dialog" aria-labelledby="exampleModalLabel" aria-hidden="true">
        <div class="modal-dialog modal-dialog-centered" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h3>Add Participant</h3>
                    <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                        <span aria-hidden="true">&times;</span>
                    </button>
                </div>
                <form action="{{ route('user.store') }}" method="POST">
                    @csrf
                    <div class="modal-body">
                        <div class="form-group">
                            <div class="col-md-12">
                                <label for="name" class="col-md-6">Name</label>
                                <input type="text" name="name" class="form-control col-md-12" value="{{ old('name') }}" required>
                                @error('name')
                                <span class="invalid-feedback" role="alert">
                                    <strong>{{ $message }}</strong>
                                </span>
                                @enderror
                            </div>
                        </div>
                        <div class="form-group">
                            <div class="col-md-12">
                                <label for="score" class="col-md-6">Hours</label>
                                <input type="number" name="score" class="form-control col-md-12 @error('score') is-invalid @enderror" value="{{ old('score') }}" required>
                                @error('score')
                                <span class="invalid-feedback" role="alert">
                                    <strong>{{ $message }}</strong>
                                </span>
                                @enderror
                            </div>
                        </div>
                        <div class="form-group">
                            <div class="col-md-12">
                                <label for="score" class="col-md-6">Minutes</label>
                                <input type="number" name="minutes" class="form-control col-md-12 @error('minutes') is-invalid @enderror" value="{{ old('minutes') }}" required>
                                @error('minutes')
                                <span class="invalid-feedback" role="alert">
                                    <strong>{{ $message }}</strong>
                                </span>
                                @enderror
                            </div>
                        </div>
                        <div class="form-group">
                            <div class="col-md-12">
                                <label for="score" class="col-md-6">Seconds</label>
                                <input type="number" name="seconds" class="form-control col-md-12 @error('seconds') is-invalid @enderror" value="{{ old('seconds') }}" required>
                                @error('seconds')
                                <span class="invalid-feedback" role="alert">
                                    <strong>{{ $message }}</strong>
                                </span>
                                @enderror
                            </div>
                        </div>
                        <div class="form-group">
                            <div class="col-md-12">
                                <label for="score" class="col-md-6">Milliseconds</label>
                                <input type="text" name="milli" class="form-control col-md-12 @error('milli') is-invalid @enderror" value="{{ old('milli') }}" required>
                                @error('milli')
                                <span class="invalid-feedback" role="alert">
                                    <strong>{{ $message }}</strong>
                                </span>
                                @enderror
                            </div>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="submit" class="btn btn-primary">Add</button>
                        <button type="button" class="btn btn-secondary" data-dismiss="modal">Close</button>
                    </div>
                </form>
            </div>
        </div>
    </div>


@endsection